window.Gleam.initSearch([{"doc":"fresnel","title":"fresnel","content":"# fresnel\n\n[![Package Version](https://img.shields.io/hexpm/v/fresnel)](https://hex.pm/packages/fresnel)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fresnel/)\n\n✨ Make your actors shine 🎭\n\nfresnel is a library to help in working with the OTP framework and actors in gleam. The current supported\nfeatures include:\n\n- Round Robin load balancer actor for distributing messages across multiple actor targets\n- Fan Out Pub/Sub actor for distributing messages across all subscribed actors\n\n## Usage\n\n```sh\ngleam add fresnel\n```\n```gleam\nimport fresnel/fan_out\nimport gleam/otp/actor\nimport gleam/erlang/process\nimport gleam/io\n\ntype Event {\n  Lights\n  Camera\n  Action\n}\n\nfn subscriber(event: Event, id: String) -&gt; actor.Next(Event, String) {\n  case event {\n    Lights -&gt; {\n      io.println(id&lt;&gt;&quot;: lights&quot;)\n      actor.continue(id)\n    }\n    Camera -&gt; {\n      io.println(id&lt;&gt;&quot;: camera&quot;)\n      actor.continue(id)\n    }\n    Action -&gt; {\n      io.println(id&lt;&gt;&quot;: action!&quot;)\n      actor.continue(id)\n    }\n  }\n}\n\npub fn main() {\n  let assert Ok(publisher) = actor.start([], fan_out.handler)  \n  let assert Ok(listener1) = actor.start(&quot;1&quot;, subscriber)\n  let assert Ok(listener2) = actor.start(&quot;2&quot;, subscriber)\n  process.send(publisher, Lights)\n  process.send(publisher, Camera)\n  process.send(publisher, Action)\n}\n```\n\noutputs:\n```\n1: lights\n2: lights\n1: camera\n2: camera\n1: action!\n2: action!\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fresnel&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"fan_out","title":"Message","content":"pub type Message(e) {\n  Subscribe(Subject(e))\n  Unsubscribe(Subject(e))\n  Publish(e)\n}\n Messages that can be sent to the fan_out publisher actor.\nSubscribe(Subject(e))\n Add a new subscriber that will begin receiving events\n\nUnsubscribe(Subject(e))\n Remove a subscriber from receiving published messages\n\nPublish(e)\n Publish an event to all subscribers\n\nSynonyms:\nfan_out.Message\nfan_out Message","url":"fan_out.html#Message"},{"doc":"fan_out","title":"handler","content":"pub fn handler(\n  msg: Message(a),\n  subscribers: List(Subject(a)),\n) -&gt; Next(Message(a), List(Subject(a)))\n The handler to start the round robin actor\n\n Examples:\n \n import fresnel/fan_out\n import gleam/otp/actor\n import gleam/erlang/process\n import gleam/io\n\n type Event {\n   Lights\n   Camera\n   Action\n }\n\n fn subscriber(event: Event, id: String) -&gt; actor.Next(Event, String) {\n   case event {\n     Lights -&gt; {\n       io.println(id&lt;&gt;&quot;: lights&quot;)\n       actor.continue(id)\n     }\n     Camera -&gt; {\n       io.println(id&lt;&gt;&quot;: camera&quot;)\n       actor.continue(id)\n     }\n     Action -&gt; {\n       io.println(id&lt;&gt;&quot;: action!&quot;)\n       actor.continue(id)\n     }\n   }\n }\n\n pub fn main() {\n   let assert Ok(publisher) = actor.start([], fan_out.handler)  \n   let assert Ok(listener1) = actor.start(&quot;1&quot;, subscriber)\n   let assert Ok(listener2) = actor.start(&quot;2&quot;, subscriber)\n   process.send(publisher, Lights)\n   process.send(publisher, Camera)\n   process.send(publisher, Action)\n }\n \nSynonyms:\nfan_out.handler\nfan_out handler","url":"fan_out.html#handler"},{"doc":"fan_out","title":"fan_out","content":" An actor that distributes published messages to all subscribed subject. \n Subjects can be dynamically subscribed or unsubscribed from the publisher.","url":"fan_out.html"},{"doc":"fresnel","title":"fresnel","content":"","url":"fresnel.html"},{"doc":"roundrobin","title":"Message","content":"pub type Message(e) {\n  Register(Subject(e))\n  Unregister(Subject(e))\n  Push(e)\n}\n Messages that can be sent to the Roundrobin actor.\nRegister(Subject(e))\n Registeres a new loadbalancer target\n\nUnregister(Subject(e))\n Removes a loadbalancer target\n\nPush(e)\n Emit an event that will be loadbalanced to the registered targets\n\nSynonyms:\nroundrobin.Message\nroundrobin Message","url":"roundrobin.html#Message"},{"doc":"roundrobin","title":"handler","content":"pub fn handler(\n  msg: Message(a),\n  targets: List(Subject(a)),\n) -&gt; Next(Message(a), List(Subject(a)))\n The handler to start the round robin actor\n\n # Examples:\n \n import fresnel/roundrobin\n import gleam/otp/actor\n import gleam/erlang/process\n import gleam/io\n\n type Event {\n   Lights\n   Camera\n   Action\n }\n\n fn target(event: Event, id: String) -&gt; actor.Next(Event, String) {\n   case event {\n     Lights -&gt; {\n       io.println(id&lt;&gt;&quot;: lights&quot;)\n       actor.continue(id)\n     }\n     Camera -&gt; {\n       io.println(id&lt;&gt;&quot;: camera&quot;)\n       actor.continue(id)\n     }\n     Action -&gt; {\n       io.println(id&lt;&gt;&quot;: action!&quot;)\n       actor.continue(id)\n     }\n   }\n }\n\n pub fn main() {\n   let assert Ok(loadbalancer) = actor.start([], roundrobin.handler)  \n   let assert Ok(listener1) = actor.start(&quot;1&quot;, target)\n   let assert Ok(listener2) = actor.start(&quot;2&quot;, target)\n   process.send(loadbalancer, Lights)\n   process.send(loadbalancer, Camera)\n   process.send(loadbalancer, Action)\n }\n \nSynonyms:\nroundrobin.handler\nroundrobin handler","url":"roundrobin.html#handler"},{"doc":"roundrobin","title":"roundrobin","content":" An actor that load balances pushed messages to registered subjects in a roundrobin fashion. \n Subjects can be dynamically registered and unregistered","url":"roundrobin.html"}]);